@@ -1,21 +1,36 @@
 /*
  * Copyright 2020 Han Young <hanyoung@protonmail.com>
- * Copyright 2020 Devin Lin <espidev@gmail.com>
+ * Copyright 2020-2021 Devin Lin <devin@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "utilmodel.h"
+#include "settingsmodel.h"
 
 #include <QLocale>
+#include <QStandardPaths>
 #include <QString>
 #include <QTimeZone>
+#include <QUrl>
 
 #include <KLocalizedString>
 
+UtilModel *UtilModel::instance()
+{
+    static UtilModel *singleton = new UtilModel;
+    return singleton;
+}
+
+QString UtilModel::getDefaultAlarmFileLocation()
+{
+    return QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("sounds/freedesktop/stereo/alarm-clock-elapsed.oga")))
+        .path();
+}
+
 QString UtilModel::getCurrentTimeZoneName()
 {
-    return QTimeZone::systemTimeZoneId();
+    return QString::fromStdString(QTimeZone::systemTimeZoneId().toStdString());
 }
 
 long long UtilModel::calculateNextRingTime(int hours, int minutes, int daysOfWeek, int snooze)
@@ -44,7 +59,7 @@ long long UtilModel::calculateNextRingTime(int hours, int minutes, int daysOfWee
 
         return QDateTime(date.date(), alarmTime).toSecsSinceEpoch();
     }
-};
+}
 
 QString UtilModel::timeToRingFormatted(const long long &timestamp)
 {
@@ -78,12 +93,22 @@ QString UtilModel::timeToRingFormatted(const long long &timestamp)
     }
 }
 
-bool UtilModel::isLocale24HourTime()
+QString UtilModel::timeFormat()
 {
-    return QLocale::system().timeFormat(QLocale::ShortFormat).toLower().indexOf("ap") == -1;
+    return use24HourTime() ? QStringLiteral("hh:mm") : QStringLiteral("hh:mm ap");
 }
 
-void UtilModel::setSelectedTimezone(QByteArray id, bool selected)
+bool UtilModel::use24HourTime()
 {
-    Q_EMIT selectedTimezoneChanged(id, selected);
+    QString timeFormat = SettingsModel::instance()->timeFormat();
+    if (timeFormat == QStringLiteral("SystemDefault")) {
+        return isLocale24HourTime();
+    } else {
+        return timeFormat == QStringLiteral("24Hour");
+    }
+}
+
+bool UtilModel::isLocale24HourTime()
+{
+    return QLocale::system().timeFormat(QLocale::ShortFormat).toLower().indexOf(QStringLiteral("ap")) == -1;
 }
