@@ -19,12 +19,25 @@ AlarmPlayer &AlarmPlayer::instance()
 
 AlarmPlayer::AlarmPlayer(QObject *parent)
     : QObject{parent}
-    , m_player{new QMediaPlayer(this, QMediaPlayer::LowLatency)}
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+, m_player(new QMediaPlayer(this)), m_audio(new QAudioOutput)
+#else
+, m_player(new QMediaPlayer(this, QMediaPlayer::LowLatency))
+#endif
 {
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+    m_player->setAudioOutput(m_audio);
+    connect(m_player, &QMediaPlayer::playbackStateChanged, this, &AlarmPlayer::loopAudio);
+#else
     connect(m_player, &QMediaPlayer::stateChanged, this, &AlarmPlayer::loopAudio);
+#endif
 }
 
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+void AlarmPlayer::loopAudio(QMediaPlayer::PlaybackState state)
+#else
 void AlarmPlayer::loopAudio(QMediaPlayer::State state)
+#endif
 {
     if (!userStop
         && state == QMediaPlayer::StoppedState /* && static_cast<int>(QDateTime::currentSecsSinceEpoch() - startPlayingTime) < settings.alarmSilenceAfter()*/) {
@@ -34,7 +47,11 @@ void AlarmPlayer::loopAudio(QMediaPlayer::State state)
 
 void AlarmPlayer::play()
 {
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+    if (m_player->playbackState() == QMediaPlayer::PlayingState) {
+#else
     if (m_player->state() == QMediaPlayer::PlayingState) {
+#endif
         return;
     }
 
@@ -51,12 +68,20 @@ void AlarmPlayer::stop()
 
 int AlarmPlayer::volume()
 {
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+    return m_audio->volume() * 100;
+#else
     return m_player->volume();
+#endif
 }
 
 void AlarmPlayer::setVolume(int volume)
 {
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+    m_audio->setVolume(static_cast<float>(volume) / 100);
+#else
     m_player->setVolume(volume);
+#endif
     Q_EMIT volumeChanged();
 }
 
@@ -64,9 +89,18 @@ void AlarmPlayer::setSource(QUrl path)
 {
     // if user set a invalid audio path or doesn't even specified a path, resort to default
     if (!path.isValid() || !QFile::exists(path.toLocalFile())) {
-        m_player->setMedia(QUrl::fromLocalFile(
-            QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("sounds/freedesktop/stereo/alarm-clock-elapsed.oga"))));
+        const QUrl url = QUrl::fromLocalFile(
+            QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("sounds/freedesktop/stereo/alarm-clock-elapsed.oga")));
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+        m_player->setSource(url);
+#else
+        m_player->setMedia(url);
+#endif
     } else {
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+        m_player->setSource(path);
+#else
         m_player->setMedia(path);
+#endif
     }
 }
